.. _AUTHORS:

Authors
=======

Developers
~~~~~~~~~~

* Rikard Nordgren, rikard.nordgren@farmaci.uu.se, (maintainer)
* Stella Belin, stella.belin@farmaci.uu.se, (maintainer)
* Gunnar Yngman, gunnar.yngman@farmaci.uu.se
* Kajsa Harling
* Mats Karlsson
* Andrew Hooker
* Simon Carter
